<!-- docs/_sidebar.md -->

# [Installation + Tech Notes](/)

* [Installation](/)

# [Usage](/how-to)

* [How To](/how-to)

    * [Getting Started](/getting-started)
    * [Loading Data](/loading-data)
    * [Basic Data Exploration](/basic-data-exploration)
        * [Intermediate Data Manipulation](/data-manipulation)
        * [Custom `.S` Functionality](/dot-S-functionality)
        * [Custom `.T` Functionality](/dot-T-functionality)
    * [Curve Fitting](/curve-fitting)
    * [K-space Conversion](/k-space-conversion)
    * [Fermi Edge Corrections](/fermi-edge-corrections)
    * [Interactive Analysis Tools](/interactive)
    * [Statistics](/statistics)
    * [Advanced Plotting](/advanced-plotting)
        * [Stack Plots](/stack-plots)
        * [Brillouin Zones](/brillouin-zones)
        * [Fermi Surfaces](/fermi-surfaces)
        * [3D Cut Plots](/3d-cut-plots)
        * [Spin-ARPES Plots](/spin-arpes)
        * [Ultrafast-ARPES Plots](/tr-arpes)
        * [Annotations](/annotations)
        * [Labeling + Utilities](/plotting-utilities)
    * [Adding a Beamline/Lab Source](/writing-plugins)
    * [Contributing](/contributing)
    * [Customization and Notes on Juypyter](/customization)
    
* [Topics](/how-to)
    * [Condensed Matter Physics Software Stack](/cmp-stack)
    * [Analysis Spreadsheets](/spreadsheets)
    * [Spectra + Data Representation](/spectra)
    * [Plugins](/writing-plugins)
    * [Data Provenance](/data-provenance)
    * [Phenomenological and Detector Models](/modeling)
